@@ -9,9 +9,11 @@
 mod checks;
 mod cli;
 mod config;
+mod prompt;
 use colored::Colorize;
 use config::Challenge;
 use log::debug;
+use regex::Regex;
 use std::process::exit;
 
 fn main() {
@@ -37,6 +39,11 @@ fn main() {
     if let Some(validate_matches) = matches.subcommand_matches("pre-command") {
         let command = validate_matches.value_of("command").unwrap();
 
+        let command = Regex::new(r#"('|")([\s\S]*?)('|")"#)
+            .unwrap()
+            .replace_all(command, "")
+            .to_string();
+
         let conf = match config_dir.load_config_from_file() {
             Ok(conf) => conf,
             Err(e) => {
@@ -49,19 +56,29 @@ fn main() {
             }
         };
 
-        let matches = checks::run_check_on_command(&conf.checks, command);
-
-        debug!("matches found {}. {:?}", matches.len(), matches);
-
-        let mut exit_code = 0;
-        for m in matches {
-            if !m.show(&conf.challenge, validate_matches.is_present("test")) {
-                exit_code = 1;
-                break;
-            }
+        // to be able push changes when releasing new version,
+        // we can check if the config file is different then app version.
+        // if yes we should do the following steps:
+        // 1. update the config version
+        // 2. adding/remove checks the changed from the baseline code
+        if conf.version != env!("CARGO_PKG_VERSION") {
+            config_dir.update_config_version(conf).unwrap();
+            return;
         }
 
-        exit(exit_code);
+        let matches = checks::run_check_on_command(&conf.checks, &command);
+
+        debug!("matches found {}. {:?}", matches.len(), matches);
+        let mut success = true;
+        if !matches.is_empty() {
+            success = checks::challenge(
+                &conf.challenge,
+                &matches,
+                validate_matches.is_present("test"),
+            );
+        }
+
+        exit(!success as i32);
     } else if let Some(validate_matches) = matches.subcommand_matches("config") {
         if let Some(update_matches) = validate_matches.subcommand_matches("update") {
             let check_groups: Vec<&str> =
